* 2018_eseg08_silc.do EU-SILC
* STATA Command Syntax File
* Stata 17.0;
*
* Wirth, Heike/Judith Gilsbach (2022): 2018_eseg08_silc.do
* https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling
*
* This syntax generates European Socio-Economic Groups (ESEG 2008) for EU-SILC Data
* using the P-File (personal data) & R-FILE (personal register data).
* ESeG_1 (less detailed)
* ESeG_2 (detailed)
*
* For details on ESeG please see 
* Meron, Monique et al. (2014)
* Final Report of the ESSnet on the harmonisation and implementation of a 
* European socio-economic classification: 
* European Socio-economic Groups (ESeG)
* Links:
* [0] https://ec.europa.eu/eurostat/cros/content/eseg-report-technicaldocuments_en
* [1] https://ec.europa.eu/eurostat/cros/system/files/ESEG-Report-TechnicalAnnexes_0.zip_en
* [2] https://ec.europa.eu/eurostat/cros/content/eseg_en
* 
* This Stata-code is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU Affero General Public License for more details.
*
* <https://www.gnu.org/licenses/>.
*
* EU-SILC P-File (personal data):
* UDB_c18P_ver 2021_09.csv
*
* For transforming the CSV-data (as released by Eurostat) into Stata-data (*.dta),
* please use the corresponding STATA Command Syntax File published at 
* http://www.gesis.org/missy/eu/setups/EU-SILC
*
* (c) GESIS 02/23/2022
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Heike Wirth, Judith Gilsbach
* http://www.gesis.org/en/institute/
* https://www.gesis.org/gml/european-microdata/eu-silc/
* https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling
*
* Contact: heike.wirth@gesis.org
*

/* Initialization commands */

clear
capture log close
set more off
version 13.0
set linesize 250
set varabbrev off


* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
* CONFIGURATION SECTION - Start 

*set working directory for temporarily saved data
cd "Specify your working directory here, no quotation marks needed"

* The following command should contain the complete path and
* name of the Stata log file.
* Change LOG_FILENAME to your filename 
local log_file "LOG_FILENAME"

* name of the SILC R-file, usual file extension "dta".
* Change R_FILENAME to your filename 
* The following command should contain the complete path and filename if not in working directory
local R_file "R_FILENAME"

* name of the SILC P-file, usual file extension "dta".
* Change P_FILENAME to your filename
* The following command should contain the complete path and filename if not in working directory
local P_file "P_FILENAME"


* CONFIGURATION SECTION - End 
* There should be probably nothing to change below this line 
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 

log using "`log_file'", replace 
numlabel _all, add


************************************************************************************************
*  Good to know
*
*      There are country specific anonymisation rules in EU-SILC for DE, MT, SI and PT 
*      DE, MT, SI: ISCO08 is provided only for major groups (1-digit)
*      PT: ISCO08 sub-major groups 11, 12, 13 are merged with sub-major group 14  
*         
*
*   => DE, MT, SI: For Malta and Slowenia there is no ESeG generated
*   => PT: For Portugal there is no differentiation between higher and lower Manager 
*
*   Unemployed persons (PL031=5) are classified according to their last job.
*      If there is no information available, unemployed persons are classified as non-active
*      Persons 
*
*   Non-active persons (PL031=6,7,8,10,11) are split into two groups.
*     Group 8: retired people and non-employed people aged 65 or more
*     
*     Group 9: Non-active persons aged less than 65 years who couldn't be classified according to their
*              last job in one of seven ESEG groups
* 
************************************************************************************************


************************************************************************************************
*
* Variables used
* PB020: Country (alphanumeric)
* PL051: ISCO08  (2-digit) current/last; DE, MT, SI: 1-digit; PT: coarsend
* PL040: Status in employment (current/last) => family workers are classified as self-employed
* PL031: self-defined current economic status (current)
* Age = either constructed by using PB140: Year of birth & PB010  year of data collection
* RX010: Age at time of interview (preferred option)
* Further variables needed when merging R-File and P-File
* RB010 RB020 RX030 RB030 RX010
* PB010 PB020 PX030 PB030
* 
************************************************************************************************

*prepare R-File for merging and make it O-file
use  "`R_file'", clear
keep RB010 RB020 RX030 RB030 RX010
rename (RB010 RB020 RX030 RB030 RX010) (PB010 PB020 PX030 PB030 RX010)
save O_file, replace

*load P-File for merging
use  "`P_file'", clear

*Merge
merge 1:1 PB010 PB020 PX030 PB030 using O_file.dta
keep if _merge == 3

numlabel _all, add

*rename age variable
gen age = RX010
*rename isco08  
gen isco08 = PL051

replace isco08=. if PB020=="DE"
replace isco08=. if PB020=="MT"
replace isco08=. if PB020=="SI"
tab isco08 PB020


* Generating employment status variable
* Family workers are defined as self-employed 
	gen sta = PL040
	replace sta = 1 if PL040 == 1 | PL040 == 2 | PL040 == 4 
	replace sta = 2 if PL040 == 3  
	
	label define stalbl 1 "self-employed" 2 "employed"
    label values sta stalbl
	
	tab sta PL040 
	
* eseg_1 = aggregated level 
	
	gen eseg_1 = . 


* Assigning eseg to respondents with self-defined current economic status (PL031): self-employed, employed, unemployed, in compulsory military community or service
	replace eseg_1 = 1 if ((isco08 >=11 & isco08 <=14)&(sta == 1 | sta == 2)) | (isco08 == 01 & sta == 2) & ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 2 if ((isco08 >=21 & isco08 <=26)&(sta == 1 | sta == 2))& ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 3 if ((isco08 >=31 & isco08 <=35)|(isco08 == 2))& (sta == 2)& ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 4 if ((isco08 >=31 & isco08 <=96) & sta == 1)& ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 5 if ((isco08 >=41 & isco08 <=44)|(isco08 ==53 | isco08 ==54 | isco08 ==3))& (sta == 2) & ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 6 if ((isco08 >=71 & isco08 <=83) & sta == 2) & ((PL031 >=1 & PL031 <=5) | (PL031==9))
	replace eseg_1 = 7 if ((isco08 ==51 | isco08 ==52)|(isco08 >=61 & isco08 <=63)|(isco08 >=91 & isco08 <=96))& (sta == 2)& ((PL031 >=1 & PL031 <=5) | (PL031==9))
 
* Respondents <65, unemployed, no eseg assigned yet are set to eseg 9 'other non-employed persons'
  replace eseg_1 = 9 if eseg_1 == . & age < 65 & PL031 == 5
	
* All other respondents, unemployed and neither in eseg 1-7 nor in eseg 9 are set to eseg 8 'Retired persons'
  replace eseg_1 = 8 if eseg_1 == . & PL031 == 5

* Respondents  <65 and non-employed according to PL031 (6,8,10,11) are set to eseg 9 'other non-employed persons'
  replace eseg_1 = 9 if  ((PL031 ==6 | PL031 == 8 | PL031 ==10 | PL031 == 11) & age <= 64) | age <= 14
 
* Respondents  >64 and non-employed  are set to eseg 8  'Retired persons'
  replace eseg_1 = 8 if    PL031 ==7 | ((age >=65& age<99)  & (PL031 ==5 | PL031 ==6 | PL031 ==7 | PL031 ==8 | PL031 ==10 | PL031 ==11 | PL031 ==.))

* ESeG for Germany, Malta and Slowenia is set to missing value,  because of country specific anonymisation (ISCO08 only available as 1-digit)
  replace eseg_1 = . if PB020=="DE"
  replace eseg_1 = . if PB020=="MT"
  replace eseg_1 = . if PB020=="SI"

	
lab def eseg_1 ///
1 "Manager" ///
2 "Professionals" ///
3 "Technicians and associated professeional employees" ///
4 "Small entrepreneur" ///
5 "Clerks and skilled service employees" ///
6 "Industrial skilled employees" ///
7 "Less skilled employees"  ///
8 "Retired persons (and non-employed people >=65)" ///
9 "Other non-employed persons aged < 65" 
lab value eseg_1 eseg_1

tab eseg_1

* eseg_2 = detailed level 

	gen eseg_2 = . 
	
/* Definition
1	Managers
1.1	Higher managerial self-employed  (ISCO 11, 12, 13 and status=se)
1.2	Lower managerial self-employed  (ISCO 14 and status=se)
1.3	Higher managerial employees   (ISCO 11, 12, 13 and 01 and status=e)
1.4	Lower managerial employees   (ISCO 14 and status=e)
*/
	
	replace eseg_2 = 11 if ((isco08 == 11 | isco08 == 12 | isco08 == 13) & sta == 1) & (eseg_1 > 0 & eseg_1 < 8)  
	replace eseg_2 = 12 if (isco08 == 14 & sta == 1) & eseg_1 > 0 & eseg_1 < 8 
	replace eseg_2 = 13 if ((isco08 == 01 | isco08 == 11 | isco08 == 12 | isco08 == 13) & sta == 2) & eseg_1 > 0 & eseg_1 < 8 
	replace eseg_2 = 14 if (isco08 == 14 & sta == 2) & eseg_1 > 0 & eseg_1 < 8 
	
/* Definition
2	Professionals
2.1	Science, engineering and information and communications technology (ICT) professionnals (ISCO 21,25)
2.2	Health professionals  (ISCO 22)
2.3	Business and administration professionals  (ISCO 24)
2.4	Legal, social and cultural professionals  (ISCO 26)
2.5	Teaching professionals  (ISCO 23)  
*/

	replace eseg_2 = 21 if (isco08 == 21 | isco08 == 25) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 22 if (isco08 == 22) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 23 if (isco08 == 24) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 24 if (isco08 == 26) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 25 if (isco08 == 23) & (eseg_1 > 0 & eseg_1 < 8) 
	
/* Definition
3	Technicians and associated professionals employees (status= e)
3.1	Science, engineering and ICT technicians and associated professionals (ISCO 31, 35)
3.2	Health associate professionals  (ISCO 32)
3.3	Business and administration associate professionals  (ISCO 33)
3.4	Legal, social and cultural associate professionals  (ISCO 34)
3.5	Non-commissioned armed forces officers  (ISCO 02 )
*/
	
	replace eseg_2 = 31 if ((isco08 == 31 | isco08 == 35) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 32 if (isco08 == 32 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 33 if (isco08 == 33 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 34 if (isco08 == 34 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 35 if (isco08 == 02 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	
/* Definition
4	Small entrepreneurs  (status= se)
4.1	Skilled agricultural self employed workers  (ISCO 6)
4.2	Technicians, clerical support, services and sales self employed workers  (ISCO 3, 4, 5)
4.3	Craft and related trades self employed workers  (ISCO 7, 8, 9)
*/

	replace eseg_2 = 41 if ((isco08 >=61 & isco08 <=63) & sta== 1) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 42 if ((isco08 >=31 & isco08 <=54) & sta== 1) & (eseg_1 > 0 & eseg_1 < 8)  
	replace eseg_2 = 43 if ((isco08 >=71 & isco08 <=96) & sta== 1) & (eseg_1 > 0 & eseg_1 < 8) 
	
/* Definition
5	Clerks and skilled service workers  (status=e)
5.1	General and numerical clerks and other clerical support employees  (ISCO 41, 43, 44)
5.2	Customer services clerks  (ISCO 42)
5.3	Personal care employees  (ISCO 53)
5.4	Armed forced occupations and protective service employees  (ISCO 03 and ISCO 54)
*/

	replace eseg_2 = 51 if ((isco08 ==41 | isco08 == 43 | isco08 == 44) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 52 if (isco08 == 42 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 53 if (isco08 == 53 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 54 if ((isco08 ==03 | isco08 == 54) & sta== 2) & (eseg_1 > 0 & eseg_1 < 8) 
	
/* Definition
6	Industrial and agricultural employees  (status= e)
6.1	Building and related trade employees  (ISCO 71)
6.2	Food processing, wood working, garment employees  (ISCO 75)
6.3	Metal, machinery, handicraft, printing, electrical and electronic trades employees  (ISCO 72, 73, 74)
6.4	Stationary plant and machine operators and assemblers  (ISCO 81, 82)
6.5	Drivers  (ISCO 83)
*/

	replace eseg_2 = 61 if (isco08 == 71 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 62 if (isco08 == 75 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 63 if ((isco08 ==72 | isco08 == 73 | isco08 == 74) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 64 if ((isco08 ==81 | isco08 == 82) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 65 if (isco08 == 83 & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 

/* Definition
7	Less skilled workers (status= e)
7.1	Personal services and sales employees (ISCO 51, 52)
7.2	Blue collar employees and food preparation assistants in elementary occupations (ISCO 92, 93, 94, 96)  
7.3	Cleaners and helpers and services employees in elementary occupations (ISCO 91, 95)
7.4	Agricultural employees  (ISCO  6)
*/

	replace eseg_2 = 71 if ((isco08 == 51 | isco08 == 52) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 72 if ((isco08 == 92 | isco08 == 93 | isco08 == 94 | isco08 == 96) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 73 if ((isco08 == 91 | isco08 == 95) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 
	replace eseg_2 = 74 if ((isco08 >=61 & isco08 <=63) & sta == 2) & (eseg_1 > 0 & eseg_1 < 8) 	
	
/* Definition
8	Retired persons (and persons not employed  65 years or more)
8.1	Retired Managers
8.2	Retired professionals
8.3	Retired technicians and associate professionals
8.4	Retired small entrepreneurs
8.5	Retired skilled service workers 
8.6	Retired skilled blue-collars
8.7	Retired less skilled workers
8.8	Other inactive aged 65 or more
*/

	replace eseg_2 = 81 if (((isco08 >=11 & isco08 <=14) &(sta == 1 | sta == 2)) | (isco08 == 01 & sta == 2)) & eseg_1 == 8 
	replace eseg_2 = 82 if ((isco08 >=21 & isco08 <=26) & (sta == 2 | sta == 1)) & eseg_1 == 8 
	replace eseg_2 = 83 if (((isco08 >=31 & isco08 <=35) & sta == 2) | (isco08 == 02 & sta == 2)) & eseg_1 == 8 
	replace eseg_2 = 84 if ((isco08 >=31 & isco08 <=96) & sta == 1) & eseg_1 == 8 
	replace eseg_2 = 85 if (((isco08 >=41 & isco08 <=44)| isco08 == 03 | isco08 == 53 | isco08 == 54) & sta == 2) & eseg_1 == 8 
	replace eseg_2 = 86 if ((isco08 >=71 & isco08 <=83) & sta == 2) & eseg_1 == 8 
	replace eseg_2 = 87 if (((isco08 >=61 & isco08 <=63)|(isco08 >=91 & isco08 <=96) | isco08 == 51 | isco08 == 52) & sta == 2) & eseg_1 == 8 
	replace eseg_2 = 88 if missing(eseg_2) & eseg_1 == 8 
	
	
	/* Definition
9	Other non employed persons
9.1	Students
9.2	Permanently disabled 
9.3	Unemployed not elsewhere classified 
9.4	Other inactive aged less than 65 years
*/

	replace eseg_2 = 91 if PL031 == 6 & eseg_1 == 9 
	replace eseg_2 = 92 if PL031 == 8 & eseg_1 == 9 
	replace eseg_2 = 93 if PL031 == 5 & eseg_1 == 9 
	replace eseg_2 = 94 if (PL031 == 9 | PL031 == 10 | PL031 == 11) & eseg_1 == 9 
	replace eseg_2 = . if missing(eseg_1)  

	
lab def eseg_2 ///
11 "Higher managerial self-employed" ///
12 "Lower managerial self-employed" ///
13 "Higher managerial employees" ///
14 "Lower managerial employees" ///
21 "Science, engineering and information and communications technology (ICT) professionals" ///
22 "Health professionals" ///
23 "Business and administration professionals" ///
24 "Legal, social and cultural professionals" ///
25 "Teaching professionals" ///
31 "Science, engineering and ICT technicians and associated professionals" ///
32 "Health associate professionals" ///
33 "Business and administration associate professionals" ///
34 "Legal, social and cultural associate professionals" ///
35 "Non-commissioned armed forces officers" ///
41 "Skilled agricultural self-employed workers" ///
42 "Technicians, clerical support, services and sales self-employed workers" ///
43 "Craft and related trades self-employed workers" ///
51 "General and numerical clerks and other clerical support employees" ///
52 "Customer services clerks" ///
53 "Personal care employees" ///
54 "Armed forced occupations and protective service employees" ///
61 "Building and related trade employees" ///
62 "Food processing, wood working, garment employees" ///
63 "Metal, machinery, handicraft, printing, electrical and electronic trades employees" ///
64 "Stationary plant and machine operators and assemblers" ///
65 "Drivers" ///
71 "Personal services and sales employees" ///
72 "Blue collar employees and food preparation assistants in elementary occupations" ///
73 "Cleaners and helpers and services employees in elementary occupations" ///
74 "Agricultural employees" ///
81 "Retired Managers" ///
82 "Retired professionals" ///
83 "Retired technicians and associate professionals" ///
84 "Retired small entrepreneurs" ///
85 "Retired skilled white collars" ///
86 "Retired skilled blue-collars" ///
87 "Retired less skilled workers" ///
88 "Other inactive aged 65 or more" ///
91 "Students" ///
92 "Permanently disabled" ///
93 "Unemployed not elsewhere classified" ///
94 "Other inactive aged less than 65 years" 

lab value eseg_2 eseg_2 

* ESeG for Germany, Malta and Slowenia is set to missing value,  because of country specific anonymisation (ISCO08 only available as 1-digit)
  replace eseg_2 = . if PB020=="DE"
  replace eseg_2 = . if PB020=="MT"
  replace eseg_2 = . if PB020=="SI"
  
 numlabel, add
 tab1 eseg_1 eseg_2, m
 
 erase O_file.dta

 log close 
